simsopt.solve package
=====================

Submodules
----------

simsopt.solve.mpi module
------------------------

.. automodule:: simsopt.solve.mpi
   :members:
   :undoc-members:
   :show-inheritance:

simsopt.solve.permanent\_magnet\_optimization module
----------------------------------------------------

.. automodule:: simsopt.solve.permanent_magnet_optimization
   :members:
   :undoc-members:
   :show-inheritance:

simsopt.solve.serial module
---------------------------

.. automodule:: simsopt.solve.serial
   :members:
   :undoc-members:
   :show-inheritance:

